@@ -29,8 +29,8 @@ if sys.hexversion > 0x030000F0:
 else:
     import Queue
 QEmpty = Queue.Empty
+from piHAlibs import (broadcast,filterevt,printer,splitter,unduplicate)
 from piHAcontrollers import Controllers
-from piHAlibs import (broadcast,unduplicate,printer)
 from .servers import (MESSAGEq,PortInUse,SetupDaemons,SetupControllers,TXControllers)
 
 
@@ -56,7 +56,9 @@ class CONTROLLER(object):
         self.servercmds = {
             'ALLRXTX':self.allrxtx,
             'DROPDUPRX':self.dropduprx,
+            'FILTEREVENT':self.filterevent,
             'NOEVENT':self.noevent,
+            'NOSPLIT':self.nosplit,
             'STOPS':self.stops}
         self.initcontroller()
 
@@ -99,7 +101,6 @@ class CONTROLLER(object):
                 logger.debug("Added in TXControllers %s",repr(TXControllers))
 
     def cleanm(self):
-        if not self.setup: return
         for d in self.decoders:
             d.close()
             self.decoders.remove(d)
@@ -110,16 +111,16 @@ class CONTROLLER(object):
             self.features.remove(f)
         for f in self.featurenames:
             self.featurenames.remove(f)
-        if self.TXcap : del TXControllers[self.namedev]          
-        del PortInUse[self.port]
-        del SetupControllers[self.namedev]
+        if self.namedev in TXControllers: del TXControllers[self.namedev]          
+        if self.namedev in SetupControllers: del SetupControllers[self.namedev]
+        if self.port in PortInUse: del PortInUse[self.port]
         self.controller.close()
 
     def control(self):
         """
-        Control the receive loop for incoming events
+        Control the receive loop for receiving events
         """
-        if self.opened == False:
+        if self.controller.opened == False:
             logger.debug("Device %s disconnected - Break Stop",self.name)
             self.stop = True
             self.setup = False
@@ -165,7 +166,7 @@ class CONTROLLER(object):
 
     def allRXTX(self):
         self.dispatch(
-            target=broadcast(self.features)
+            target=splitter(broadcast(self.features))
             )
 
     def dropdupRX(self):
@@ -173,6 +174,16 @@ class CONTROLLER(object):
             target=unduplicate(broadcast(self.features),ellapse=3)
             )
 
+    def filterEVENT(self):
+        self.dispatch(
+            target=splitter(filterevt(broadcast(self.features),filter='FilterEVT'))
+            )
+
+    def noSPLIT(self):
+        self.dispatch(
+            target=broadcast(self.features)
+            )
+
     def allrxtx(self):
         self.tt = threading.Thread(target=self.allRXTX)
         self.startt()
@@ -181,10 +192,18 @@ class CONTROLLER(object):
         self.tt = threading.Thread(target=self.dropdupRX)
         self.startt()
 
+    def filterevent(self):
+        self.tt = threading.Thread(target=self.filterEVENT)
+        self.startt()
+
     def noevent(self):
         self.tt = threading.Thread(target=self.dispcmd)
         self.startt()
 
+    def nosplit(self):
+        self.tt = threading.Thread(target=self.noSPLIT)
+        self.startt()
+
     def startt(self):
         self.tt.name = 'CONTROLLEROf_' + self.namedev
         self.tt.start()
