@@ -17,44 +17,78 @@
 #	along with this program.  If not, see <http://www.gnu.org/licenses/>.
 # ----------------------------------------------------------------------------
 
-import logging,sys,threading,time
+import logging,os,os.path,sys,threading,time
 
-from piHAlibs import (confgetval,lst2lines)
-from .corelibs import (startscriptexe)
+from piHAlibs import (startscriptexe,confgetval,lst2lines,log2socket)
 from .coresetup import (SetupDaemons,
-    setupctrl,setupnetctrl,setupsrv,
-    startsrv,stopsrv,stopallctrls,
+    setupapp,setupctrl,setupnetctrl,setupsrv,
+    startsrv,stopsrv,stopallctrls,checkdaemon,
     )
-from .coremctrx import (mctrx)
 from .coremevtq import (mevtq)
 from .decoders import (adddecoder,rmdecoder,addparser,rmparser)
 from .rpclcmds import (RPCLocalFunctions)
 from .dfeatures import (adddfeature,rmdfeature)
 from .features import (addfeature,rmfeature)
+from .servers import (actionsched,parsched,schedunsched)
 
 
 logger = logging.getLogger()
 
 
-def runscript(param):
-    if isinstance(param,list):
-        script = param[0]
-    else:
-        script = param
+def chkscript1(param):
+    script = param.strip().lower()
     pscript = confgetval('pimucha.conf','FilesPath','STARTScript','startscript/')
-    thefile = pscript + script.lower() + '.scr'
-    lines = lst2lines(thefile)
-    if not lines:
+    thefile = os.path.join(os.getcwd(), pscript, script + '.scr')
+    if os.path.isfile(thefile): return thefile
+    return None
+
+
+def runscript(param,daemon=True):
+    if isinstance(param,list):
+        p = param[0]
+    else:
+        p = param
+    script = chkscript1(p)
+    if not script:
+        logger.error('Script file %s not present',p)
         return False
-    print('Executing %s...' % thefile)
+    lines = lst2lines(script)
+    if not lines:
+        logger.warning('Nothing to execute, script %s empty',p)
+        return False
+    logger.debug('Executing %s...' ,script)
     p = threading.Thread(target=startscriptexe, args=(SetupDaemons['SYSLOGF'],lines,))
-    p.__name__ = 'ThreadSTARTscript_' + 'script'
-    p.daemon = True
+    p.__name__ = 'ThreadSTARTscript_' + 'p'
+    p.daemon = daemon
     p.start()
-    return True
+    if daemon: return True
+    return p
 RPCLocalFunctions.append((runscript,'run'))
 
 
+def schedcmd(lparam):
+    if 'APScheduler' in SetupDaemons:
+        sched = SetupDaemons['APScheduler']
+    else:
+        return 'Server APScheduler not started'
+    p = parsched(lparam)
+    if not p: return 'Error parsing type scheduler'
+    type,cmdargs,attime = p
+    return actionsched(sched,type,CmdSched,cmdargs,attime)
+RPCLocalFunctions.append((schedcmd,'schedc'))
+
+
+def unschedcmd(lparam):
+    if 'APScheduler' in SetupDaemons:
+        sched = SetupDaemons['APScheduler']
+    else:
+        return 'Server APScheduler not started'
+    if len(lparam) == 0: return schedlistjobs(sched)
+    if isinstance(lparam,list):
+        lparam = lparam[0]
+    return schedunsched(sched,lparam)
+
+
 AdminCmds = {
     'ADDDFeature':adddfeature,
     'ADDFeature':addfeature,
@@ -62,10 +96,10 @@ AdminCmds = {
     'RMFeature':rmfeature,
     'ADDDecoder':adddecoder,
     'ADDParser':addparser,
-    'MCTRX':mctrx,
     'MEVTQ':mevtq,
     'RMDecoder':rmdecoder,
     'RMParser':rmparser,
+    'SETUPapp':setupapp,
     'SETUPctrl':setupctrl,
     'SETUPnetctrl':setupnetctrl,
     'SETUPsrv':setupsrv,
@@ -73,4 +107,13 @@ AdminCmds = {
     'STOPall':stopallctrls,
     'STOPsrv':stopsrv,
     'RUN':runscript,
+    'SCHEDC':schedcmd,
+    'UNSCHEDC':unschedcmd,
+    'DEBUG':log2socket,
+    }
+
+
+CmdSched = {
+    'CHECKDAEMON':checkdaemon,
+    'RUN':runscript,
     }
