@@ -17,19 +17,58 @@
 #	along with this program.  If not, see <http://www.gnu.org/licenses/>.
 # ----------------------------------------------------------------------------
 
-import logging,sys,time
-from piHAlibs import (adstr2addr,serverthreads)
-from .corelibs import (chksetup,chkcmdname)
+import datetime,logging,sys,time
+from piHAlibs import (chksetup,chkcmdname,adstr2addr,serverthreads,lsdict)
 from .controller import CONTROLLER
 from .decoders import (addparser,adddecoder)
 from .netcontroller import NETCONTROLLER
+from .haapps import HAAPP
 from .rpccmds import RPCFunctions
 from .rpclcmds import RPCLocalFunctions
-from .servers import (PortInUse,Servers,SetupDaemons,SetupControllers)
+from .servers import (
+    LogDaemons,PortInUse,Servers,
+    SetupDaemons,SetupControllers,
+    )
 
 logger = logging.getLogger()
 
 
+def setupapp(param):
+    """
+    param = [param0,param1,param2....]
+    param0 = name
+    param1 = idapps
+    param2 = idctrl
+    """
+    idapps = param[1].upper()
+    namedev = param[0].upper() + ':' + param[2].upper()
+    if namedev in SetupDaemons:
+        logger.error('Apps with this name is already setup %s',repr(namedev))
+        return False
+    #Init class object
+    try:
+        dev = HAAPP(param)
+        dev.namedev = namedev
+    except Exception as e:
+        logger.critical("%s : %s", repr(e.__class__), str(e))
+        logger.error('Error in init class object for %s',repr(param))
+        return False
+    #Setup daemon
+    try:
+        dev.tsetup()
+    except Exception as e:
+        logger.critical("%s : %s", repr(e.__class__), str(e))
+        logger.error('Error in setup daemon %s',repr(param))
+        return False
+    if dev.setup:
+        logdaemon(namedev,'setup')
+        logger.warning('Daemon of Apps correctly setup : %s',repr(dev))
+        return True
+    else:
+        logger.error('Error in setup Daemon of Controller %s',repr(param))
+        return False
+
+
 
 def setupctrl(param):
     """
@@ -75,6 +114,7 @@ def setupctrl(param):
         logger.error('Error in setup daemon %s',repr(param))
         return False
     if dev.setup:
+        logdaemon(namedev,'setup')
         logger.warning('Daemon of Controller correctly setup : %s',repr(dev))
         return True
     else:
@@ -96,7 +136,7 @@ def setupnetctrl(param):
         return False
     name,idctrl,port, rxtx = p
     if (rxtx is None) or (port == 'Defaults'):
-        logger.error('Syntax error with the parameter')
+        logger.error('Address and port addr:port needed')
         return False
     addr = adstr2addr(port)
     if addr in PortInUse:
@@ -126,6 +166,7 @@ def setupnetctrl(param):
         logger.error('Error in setup daemon %s',param)
         return False
     if dev.setup:
+        logdaemon(namedev,'setup')
         logger.warning('Daemon of NETController correctly setup : %s',repr(dev))
         return True
     else:
@@ -148,10 +189,16 @@ def setupsrv(param):
         if port in PortInUse:
             logger.error('The same address:port %s is already setup with %s ',port,PortInUse[port])
             return False
-    if server not in ['RPCS','TCPRX','TCPS']:
+    if server not in Servers.keys():
         logger.error('Syntax error for the type of server to setup')
+        logger.error('Servers : %s', repr( Servers.keys()))
         return False
     namesrv = name + ':' + server
+    if server == 'APScheduler':
+        if server in SetupDaemons:
+            logger.error('Server APScheduler already setup')
+            return False
+        namesrv = server
     if port == 'Defaults':
         addr = None
     else:
@@ -166,7 +213,8 @@ def setupsrv(param):
         return False
     if server == 'RPCS':
         srv.Functions += RPCFunctions
-        if port == 'Defaults': srv.Functions += RPCLocalFunctions
+        srv.Functions += RPCLocalFunctions
+        #if port == 'Defaults': srv.Functions += RPCLocalFunctions
     #Setup daemon
     try:
         srv.tsetup()
@@ -179,6 +227,7 @@ def setupsrv(param):
         PortInUse[port] = namesrv
         SetupDaemons.setdefault(namesrv)
         SetupDaemons[namesrv] = srv
+        logdaemon(namesrv,'setup')
         logger.warning('Daemon of server correctly setup : %s',repr(srv))
         return True
     else:
@@ -201,8 +250,10 @@ def startsrv(param):
         except Exception as e:
             logger.critical("%s : %s", repr(e.__class__), str(e))
             logger.error('Unable to execute %s',repr(cmd))
+            logdaemon(name,'failed')
             return False
     logger.info('Command started for %s',param)
+    logdaemon(name,'start')
     return True
 
 
@@ -223,18 +274,49 @@ def stopsrv(param):
         tt.join(5)
         if not tt.isAlive():
             logger.info('The thread instance %s is stopped.',tt.name)
-            del SetupDaemons[namectrl]
-            if namectrl.split(':')[1] in ['RPCS','TCPRX','TCPS']: del PortInUse[namectrl]
+            logdaemon(namectrl,'stop')
+            if namectrl in SetupDaemons: del SetupDaemons[namectrl]
+            if ':' in namectrl:
+                if namectrl.split(':')[1] in ['RPCS','TCPRX','TCPS']: del PortInUse[namectrl]
         return True
     if namectrl in SetupDaemons:
         logger.info('Clean memory for %s', namectrl)
         SetupDaemons[namectrl].cleanm()
+        logdaemon(namectrl,'cleanm')
         return True
     logger.info('No thread instance for %s', namectrl)
     return False
+RPCLocalFunctions.append((stopsrv, 'stopsrv'))
 
 
 def stopallctrls():
     SC = list(SetupControllers.keys())
     for ctrl in SC:
         stopsrv(SetupControllers[ctrl].namedev)
+
+
+def logdaemon(name,ope):
+    d = datetime.date.strftime(datetime.datetime.today(),"%Y-%m-%d %H:%M:%S")
+    if name not in LogDaemons:
+        LogDaemons.setdefault(name)
+        LogDaemons[name] = [None,[]]
+    LogDaemons[name][0] = ope
+    LogDaemons[name][1].append(ope + ':' + d)
+
+
+def checkdaemon(param):
+    logger.debug('Check daemon state')
+    d = datetime.date.strftime(datetime.datetime.today(),"%Y-%m-%d %H:%M:%S")
+    for s in LogDaemons:
+        if LogDaemons[s][0] == 'start':
+            a = serverthreads(s)
+            if not a: 
+                LogDaemons[s][0] = 'crash'
+                LogDaemons[s][1].append('crash:' + d)
+    if param == 'NOOUTPUT': return None
+    elif param in LogDaemons:
+        return repr(LogDaemons[param])
+    else:
+        return lsdict(LogDaemons)
+RPCLocalFunctions.append((checkdaemon, 'checkd'))
+
