@@ -18,9 +18,9 @@
 # ----------------------------------------------------------------------------
 
 import logging,time
-from piHAlibs import (confgetval,debug,log2console,log2file,printer)
+from piHAlibs import (chkparsdaemon,confgetval,debug,log2console,log2file,printer)
 from piHAparsers import (Decoders,DecoderNames,Parsers)
-from .corelibs import (chkparsdaemon)
+from .featurelibs import (rawevt2cmd)
 from .servers import (SetupDaemons)
 
 logger = logging.getLogger()
@@ -37,6 +37,7 @@ def str2fargs(param):
     elif p == 'DECREJECTED': return log2file(DECREJECTED)
     elif p == 'NEWIDS': return True
     elif p == 'LOGRAWEVT': return log2file(RAWEVT,'|')
+    elif p.startswith('RAWEVT2CMD-'): return rawevt2cmd(p.split('-')[1])
 
 
 def chkparsdecoder(params,mctrx=None):
@@ -45,12 +46,14 @@ def chkparsdecoder(params,mctrx=None):
     if not p0:
         return None
     dev,name,ctrl = p0
-    if mctrx: dev = mctrx
     if ctrl[0] == 'N': ctrl = ctrl[1:]
-    parser = ctrl + '-PARSER' 
-    if parser not in dev.featurenames:
-        logger.error('Parser Controller not yet setup %s',parser)
-        return None
+    if mctrx:
+        dev = mctrx
+    else:
+        parser = ctrl + '-PARSER' 
+        if parser not in dev.featurenames:
+            logger.error('Parser Controller not yet setup %s',parser)
+            return None
     p1 = params[1].split('(')
     decname = p1[0]
     if decname not in DecoderNames:
@@ -66,7 +69,7 @@ def chkparsdecoder(params,mctrx=None):
 def addparser(params,mctrx=None):
     """
     Add PARSER feature for controller
-    params = [name:ctrl,argparser]
+    params = [name:ctrl(,parserrejected)]
     """
     p0 = chkparsdaemon(params[0],SetupDaemons)
     if not p0:
@@ -146,24 +149,21 @@ def adddecoder(params,mctrx=None):
             args.append(str2fargs(a))
     logger.debug('Arguments for decoder %s',repr(args))
     decoder = DecoderNames[decname]
-    if decoder in Decoders[ctrl]:
-        try:
-            fct = decoder(*args)
-            dev.decoders.append(fct)
-            dev.decodernames.append(decname)
-            dev.dfeatures.append((ldfn,ldfr))
-            dev.dfeaturenames.append(lnamedf)
-            print (repr(dev.dfeatures))
-            print (repr(dev.dfeaturenames))
-            logger.info('Decoders setup %s for controller',repr(dev.decoders))
-            return True
-        except Exception as e:
-            logger.error("%s : %s", repr(e.__class__), str(e))
-            logger.error("In adding decoder %s to server %s" ,decname,dev.name)
-            return False
-    else:
+    if (not mctrx) and (decoder not in Decoders[ctrl]):
         logger.error('Decoder %s not implemented for the controller %s',decname,ctrl)
         return False
+    try:
+        fct = decoder(*args)
+        dev.decoders.append(fct)
+        dev.decodernames.append(decname)
+        dev.dfeatures.append((ldfn,ldfr))
+        dev.dfeaturenames.append(lnamedf)
+        logger.info('Decoders setup %s for controller',repr(dev.decoders))
+        return True
+    except Exception as e:
+        logger.error("%s : %s", repr(e.__class__), str(e))
+        logger.error("In adding decoder %s to server %s" ,decname,dev.name)
+        return False
 
 
 def rmdecoder(params,mctrx=None):
@@ -181,16 +181,19 @@ def rmdecoder(params,mctrx=None):
         logger.error("Decoder %s not in server decoders list %s",decname,repr(dev.decodernames))
         return False
     lnamedf = decname + '-FEATURES'
-    i = dev.decodernames.index(lnamedf)
-    ldfn,ldfr = dev.decoders[i]
-    for f in ldfr:
-        f.close()
-    dev.decoders.pop(i)
-    dev.decodernames.remove(lnamedf)
-    i = dev.decodernames.index(decname)
-    dev.decoders[i].close()
-    dev.decoders.pop(i)
-    dev.decodernames.remove(decname)
-    logger.info("Decoder %s removed for controller %s",decname,ctrl)
+    if lnamedf in dev.decodernames:
+        i = dev.decodernames.index(lnamedf)
+        ldfn,ldfr = dev.decoders[i]
+        for f in ldfr:
+            f.close()
+        dev.decoders.pop(i)
+        dev.decodernames.remove(lnamedf)
+    if decname in  dev.decodernames:
+        i = dev.decodernames.index(decname)
+        dev.decoders[i].close()
+        dev.decoders.pop(i)
+        dev.decodernames.remove(decname)
+        logger.info("Decoder %s removed for controller %s",decname,ctrl)
+    else:
+        logger.info("Decoder %s already removed from controller %s",decname,ctrl)
     return True
-
