@@ -110,6 +110,22 @@ def cmdinputf(data):
 ParseCMDS.update({'ON':cmdinputf,'OFF':cmdinputf})
 
 
+def long2short(longcmd):
+    # longcmd = '0xea 0xe2 0x00'
+    # shortcmd = 'eae200'
+    raw = longcmd.split()
+    return ''.join(["%02x" % int(i,16) for i in raw])
+
+
+def writeparser(line):
+    try:
+        wf = open('inparser.in','ab')
+        wf.write((line + "\n").encode('utf-8'))
+        wf.close()
+    except Exception as e:
+        logger.error("%s : %s", repr(e.__class__), str(e))
+
+
 def sendcmd(args,data):
     #Encode
     cmd = cmdencode(args)
@@ -126,7 +142,7 @@ def sendcmd(args,data):
         else:
             continue
         targetctrl = namedev.split(':')[1]
-        if targetctrl[0] == 'N': pass	#Pass net controller for first loop
+        if targetctrl[0]in ('L','N','P'): pass	#Pass net controller for first loop
         for ctrl in txctrls:
             if ctrl == targetctrl:
                 TXControllers[namedev].loccmdq.put_nowait(cmd[1:])
@@ -136,13 +152,30 @@ def sendcmd(args,data):
     #If cmd not send local controller, make second loop and send to net controller
     for namedev in TXControllers:
         targetctrl = namedev.split(':')[1]
-        if targetctrl[0] != 'N': pass 	#Pass local controller for second loop
+        netid = targetctrl[0]
+        if netid not in ('L','N','P'): pass #Pass local controller for second loop
         targetctrl = targetctrl[1:]
         for ctrl in txctrls:
-            if ctrl == targetctrl:
+            if (ctrl == targetctrl and netid == 'N'):
                 if isinstance(data,list) : data = ' '.join(data)
                 TXControllers[namedev].netsend(data)
                 return "Putting args in network TX queue of controller %s" % namedev
+            elif (ctrl == targetctrl and netid == 'P'):
+                rawcmd = long2short(cmd[2])
+                if ctrl == 'CM15':
+                    data = ctrl + cmd[1] + ' ' + rawcmd
+                else:
+                    data = ctrl + ' ' + rawcmd
+                TXControllers[namedev].netsend(data)
+                return "Putting data %s in network TX queue of controller %s" % (data,namedev)
+            elif (ctrl == targetctrl and netid == 'L'):
+                rawcmd = long2short(cmd[2])
+                if ctrl == 'CM15':
+                    data = 'CTRL ' + ctrl + cmd[1] + ' ' + rawcmd
+                else:
+                    data = 'CTRL ' + ctrl + ' ' + rawcmd
+                writeparser(data)
+                return "Writing data %s in parser of controller %s" % (data,namedev)
             else:
                 pass
     else:
