@@ -20,10 +20,11 @@
 import logging,threading
 
 from piHAlibs import (confgetval)
-from .actioncmds import (actionscript)
-from .corelibs import (alias2hu,huoralias,hu2alias,hudevice,lsunit)
+from .actioncmds import (actionscript,schedaction)
+from .corelibs import (alias2hu,huoralias,hu2alias,hudevice,lsunit,armdet,disarmdet)
+from .featurelibs import (launch)
 from .parsecmds import(cmdinputf,cmdinputh)
-from .servers import (INPUTq,SetupDaemons,TXControllers)
+from .servers import (INPUTq,SetupDaemons,TXControllers,schedlistjobs,schedunsched)
 
 logger = logging.getLogger()
 
@@ -34,6 +35,9 @@ phufctName = confgetval('pimucha.conf','RPCcmdName','phufctName','phufct')
 RPCFunctions = []
 RPCFunctions.append((lsunit, 'lsunit'))
 RPCFunctions.append((actionscript,'script'))
+RPCFunctions.append((armdet, 'armdet'))
+RPCFunctions.append((disarmdet, 'disarmdet'))
+RPCFunctions.append((schedaction,'sched'))
 
 
 def alias_rpc(param):
@@ -61,11 +65,15 @@ def fcthu_rpc(params):
     if len(a) == 2 and (a[0].lower() in ('on','off')):
         res = cmdinputf(params)
     else:
-        res = rpclaunch(params)
+        res = launch(params)
     return res
 RPCFunctions.append((fcthu_rpc, fcthuName))
 
 
+def launch_rpc(params):
+    return launch(params)
+RPCFunctions.append((launch_rpc,'launch'))
+
 def phufct_rpc(params):
     """
     Input : 3 parameters
@@ -92,3 +100,14 @@ def sendto_rpc(params):
     return res
 RPCFunctions.append((sendto_rpc, 'sendto'))
 
+
+def unsched_rpc(params):
+    if 'APScheduler' in SetupDaemons:
+        sched = SetupDaemons['APScheduler']
+    else:
+        return 'Server APScheduler not started'
+    if params == '': return schedlistjobs(sched)
+    return schedunsched(sched,params)
+RPCFunctions.append((unsched_rpc, 'unsched'))
+
+
