@@ -17,10 +17,44 @@
 #	along with this program.  If not, see <http://www.gnu.org/licenses/>.
 # ----------------------------------------------------------------------------
 
-from .inputparser import *
-from .rpcsrv import *
-from .syslogf import *
-from .tcptxcmd import *
-from .tcprxevt import *
 
-Servers = {'INParser':INPUTPARSER,'RPCS':RPCServer,'SYSLOGF':SYSLOGF,'TCPRX':TCPRXServer,'TCPS':TCPTXServer}
+from .inputparser import *
+from .syslogf import *
+
+Servers = {'INParser':INPUTPARSER,'SYSLOGF':SYSLOGF}
+
+
+try:
+    from .asmtprcv import ASMTPReceiver
+    Servers.update({'ASMTP':ASMTPReceiver})
+except ImportError as e:
+    print("%s : %s",( repr(e.__class__), str(e)))
+
+
+try:
+    from .rpcsrv import RPCServer
+    Servers.update({'RPCS':RPCServer})
+except ImportError as e:
+    print("%s : %s",( repr(e.__class__), str(e)))
+
+
+try:
+    from .tcptxcmd import TCPTXServer
+    Servers.update({'TCPS':TCPTXServer})
+except ImportError as e:
+    print("%s : %s",( repr(e.__class__), str(e)))
+
+
+try:
+    from .tcprxevt import TCPRXServer
+    Servers.update({'TCPRX':TCPRXServer})
+except ImportError as e:
+    print("%s : %s",( repr(e.__class__), str(e)))
+
+
+try:
+    from .apssrv import APSServer
+    Servers.update({'APScheduler':APSServer})
+    from .apsfcts import *
+except ImportError as e:
+    print("%s : %s",( repr(e.__class__), str(e)))
