@@ -20,7 +20,11 @@
 from .conflibs import *
 from .corolibs import *
 from .ctrlibs import *
+from .chklibs import *
+from .fileslibs import *
+from .menus import *
 from .newidlibs import *
+from .scriptlibs import *
 from .serverlibs import *
 from .sqlitedb import *
 from .threadlibs import *
