@@ -98,7 +98,19 @@ def fieldsdb3(tablename):
 FctDb2Dict = {
     'UNITS':["SELECT unitId,enabled,unit FROM unitIds ","(rows[i][0],list(rows[i][0:]))"],
     'UNITIDS':["SELECT iddecoder,unitId,unit FROM unitIds ","((rows[i][0],rows[i][1]),rows[i][2])"],
-    'PARAMETERS':["SELECT parameter,modaddrId,unit,enabled FROM parameterIds ","(rows[i][0:2],rows[i][0:])"],
+    'ALLUNITIDS':["SELECT iddecoder,unitId,unit FROM allunitIds ","((rows[i][0],rows[i][1]),rows[i][2])"],
+    'DETECTARM':["SELECT detectorId,armed,script,dataevent FROM detectevent ","(rows[i][0],list(rows[i][0:]))"],
+    'DETECTEVT':["SELECT rowId,detectorId,msg,dataevent,lastdtevent,tempoafter,nbhitsafter,delayprevt,nbhitsprevt,dtfirsthit FROM detectevent ","(rows[i][1],list(rows[i][0:]))"],
+    'DETECTORSTATE':["SELECT detectorId,rowId,cstatus,cdate,ctime FROM detectorstate ","(rows[i][0],rows[i][1:])"],
+    'PARAMETERS':["SELECT parameter,modaddrId,enabled,updatedmaxt FROM parameterIds ","(rows[i][0:2],rows[i][0:])"],
+    'SENSOREVT':["SELECT namelimits,applied,'2013-07-01 00:00:00',0 FROM sensorlimits ","(rows[i][0],list(rows[i]))"],
+    'SENSORSTATE':["SELECT parameter,modaddrId,rowId,cvalue,cdate,ctime FROM sensorstate ","(rows[i][0:2],rows[i][0:])"],
+    'SENSORUNT':["SELECT parameter,modaddrId,updatednt FROM sensorstate ","(rows[i][0:2],rows[i][2])"],
+    'RLAUNCHCMD':["SELECT rxdata,rowId,rxdecoded,delay,action,data FROM launchcmd ","(rows[i][0],rows[i][1:])"],
+    'ELAUNCHCMD':["SELECT rxdecoded,rowId,rxdecoded,delay,action,data FROM launchcmd ","(rows[i][0],rows[i][1:])"],
+    'LAUNCHEVAL1':["SELECT DISTINCT rxctrl,rxeval FROM launchcmd ","(rows[i][0],rows[i][1])"],
+    'LAUNCHEVAL2':["SELECT DISTINCT rxctrl,rxdevice,rxeval FROM launchcmd ","(rows[i][0:2],rows[i][2])"],
+    'LAUNCHLAST':["SELECT rowId,lastime FROM launchcmd ","(rows[i][0],rows[i][1])"],
     }
 
 
@@ -116,6 +128,7 @@ def db2dict(cnxfct,condition=None):
     return dict(a)
 
 
+
 def lsdict(dictobj):
     a = []
     for k in dictobj:
