@@ -37,24 +37,6 @@ def item2msgs(item):
 @my_fctname
 @coroutine
 def CM11parser(decoders,rejected=None):
-    """
-    item = [namedev,events]
-    split events (if several) before sending to CM11parser1
-    """
-    while True:
-        events = (yield)
-        logger.debug("Event receive %s",repr(events))
-        evts = events[1].split('|')
-        if len(evts) > 1:
-            for event in evts:
-                CM11parser1(decoders,rejected=None).send([events[0],event])
-        else:
-            CM11parser1(decoders,rejected=None).send(events)
-
-
-@my_fctname
-@coroutine
-def CM11parser1(decoders,rejected=None):
     """
     item = [namedev,event]
     Send to next target = PL decoder
