@@ -53,24 +53,6 @@ def item2msgs(item):
 @my_fctname
 @coroutine
 def RFXTRXparser(decoders,rejected=None):
-    """
-    item = [namedev,events]
-    split events (if several) before sending to RFXTRXparser1
-    """
-    while True:
-        events = (yield)
-        logger.debug("Event receive %s",repr(events))
-        evts = events[1].split('|')
-        if len(evts) > 1:
-            for event in evts:
-                RFXTRXparser1(decoders,rejected=None).send([events[0],event])
-        else:
-            RFXTRXparser1(decoders,rejected=None).send(events)
-
-
-@my_fctname
-@coroutine
-def RFXTRXparser1(decoders,rejected=None):
     """
     Parse protocol model for RFXtrx433 Controller
     item = [namedev,event]
