@@ -18,7 +18,7 @@
 # ----------------------------------------------------------------------------
 
 import logging
-from piHAlibs import (my_fctname,coroutine,db2dict,tstampdev,unitid)
+from piHAlibs import (my_fctname,coroutine,db2dict,tstampdev,unitid,newunitid)
 from .x10libs import *
 from .parsers import DETDECODERS
 
@@ -32,7 +32,10 @@ def detdecoder(targets,rejected=None,newids=None,rawevt=None):
     Decoders for X10 RF Secured detectors and remotes / RFXCom and CM15 controllers
     """
     condition = " WHERE typeunit = 'detector'"
-    ids = db2dict('UNITIDS',condition)
+    if newids:
+        ids = db2dict('ALLUNITIDS',condition)
+    else:
+        ids = db2dict('UNITIDS',condition)
     rows = DETDECODERS
     while True:
         msgs = (yield)
@@ -75,6 +78,6 @@ def detdecoder(targets,rejected=None,newids=None,rawevt=None):
         if (protocol, hu) not in ids:
             logger.debug("New detector Id %s", hu)
             if newids:
-                unitid([protocol,model,'remote',hu])
-                ids = unitid([protocol,model,'detector',hu])
+                nid = newunitid([protocol,model,'detector',hu])
+                if nid: ids.update(nid)
         if rawevt: rawevt.send([namedev,revt] + decevt)
