@@ -18,7 +18,7 @@
 # ----------------------------------------------------------------------------
 
 import logging
-from piHAlibs import (my_fctname,coroutine,db2dict,tstampdev,sensorid)
+from piHAlibs import (my_fctname,coroutine,db2dict,tstampdev,newsensorid)
 from .orelibs import *
 from .parsers import OREDECODERS
 
@@ -32,7 +32,10 @@ def oredecoder(targets,rejected=None,newids=None,rawevt=None):
     Decoders for Oregon sensor events from RFXCOM and TSDUO
     """
     condition = " WHERE typeunit = 'sensor'"
-    ids = db2dict('UNITIDS',condition)
+    if newids:
+        ids = db2dict('ALLUNITIDS',condition)
+    else:
+        ids = db2dict('UNITIDS',condition)
     rows = OREDECODERS
     while True:
         msgs = (yield)
@@ -85,7 +88,8 @@ def oredecoder(targets,rejected=None,newids=None,rawevt=None):
             logger.debug("New sensor detected %s", repr(V))
             if newids:
                 type,subtype = model2type(model)
-                ids = sensorid([protocol,model,'sensor', unit,type,subtype,row[3]])
+                nid = newsensorid([protocol,model,'sensor', unit,type,subtype,row[3]])
+                if nid: ids.update(nid)
        	    continue
        	hd = tstampdev(namedev)
        	for d in ld:
