@@ -21,7 +21,7 @@
 import logging
 logger = logging.getLogger()
 
-from piHAlibs import (my_fctname,coroutine,db2dict,tstampdev,sensorid)
+from piHAlibs import (my_fctname,coroutine,db2dict,tstampdev,newsensorid)
 try:
     from .rfxtrxlibs import *
 except ImportError as e:
@@ -36,7 +36,10 @@ def sensordecoder(targets,rejected=None,newids=None,rawevt=None):
     Decoders for Oregon sensor events from RFXTRX
     """
     condition = " WHERE typeunit = 'sensor'"
-    ids = db2dict('UNITIDS',condition)
+    if newids:
+        ids = db2dict('ALLUNITIDS',condition)
+    else:
+        ids = db2dict('UNITIDS',condition)
     rows = RFXTRXDECODERS
     while True:
         msgs = (yield)
@@ -64,11 +67,11 @@ def sensordecoder(targets,rejected=None,newids=None,rawevt=None):
             logger.debug("Address of Sensor  %s",addr)
             unit = model + '_' + addr
             V = (protocol,unit)
-       	    if V in ids:
-                unit = ids[V]
-            else:
+       	    if V not in ids:
                 logger.debug("New sensor detected %s", repr(V))
-                if newids: ids = sensorid([protocol,type + '_' + subtype,'sensor', unit,type,subtype,row[0]])
+                if newids:
+                    nid = newsensorid([protocol,type + '_' + subtype,'sensor', unit,type,subtype,row[0]])
+                    if nid: ids.update(nid)
        	        continue
        	hd = tstampdev(namedev)
        	for d in ld:
